#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 oo-prototypes
version:              0.1.0.0
visibility:           public
id:                   oo-prototypes-0.1.0.0-AI5G8RmSNbz5cEHp57CfR2
key:                  oo-prototypes-0.1.0.0-AI5G8RmSNbz5cEHp57CfR2
license:              GPL-2.0-only
maintainer:           yi-devel@googlegroups.com
author:               Mateusz Kowalczyk
homepage:             https://github.com/yi-editor/oo-prototypes
synopsis:             Support for OO-like prototypes
description:          Support for OO-like prototypes
category:             Data
abi:                  5c6287443ddaedd609553422d8ceb523
exposed:              True
exposed-modules:      Data.Prototype
import-dirs:          /usr/lib/ghc-9.6.6/site-local/oo-prototypes-0.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/oo-prototypes-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/oo-prototypes-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-oo-prototypes
hs-libraries:         HSoo-prototypes-0.1.0.0-AI5G8RmSNbz5cEHp57CfR2
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-oo-prototypes/html/oo-prototypes.haddock

haddock-html:         /usr/share/doc/haskell-oo-prototypes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

